#===============================================================================
# SCRIPT:
# Calc_Fire_Freq_And_Recency.py
#
# DESCRIPTION:
# Calculates the fire count, the most recent fire date, and the fire frequency
# for all fires, growing season fires, and dormant season fires within each
# "fire mosaic tile".
#
# USAGE:
# The user must specify a source feature class that represents overlapping fire
# history polygons and contains a field of type 'DATE' that describes when the fire occurred.
#
# The user must also specify a folder where the new output geodatabase and
# feature class will be created.
#
# Lastly, the user must specify a starting and ending date for the growing season.
#
# Author: Carl Beyerhelm (R3, Coconino National Forest), 20121204
#
# Modified by: Geoff Holden (R8, Francis Marion and Sumter National Forests), 20130611
#               - added date field input (eliminates need for number date field)
#               - added growing season start/stop date inputs
#               - tool will now ignore NULL dates which produce erroneous results
#               - changed input 'feature class' to 'feature layer' so tool will run on selected set in ArcMap
#
#               20130621 - added timestamp to output feature class name
#
# Modified by: Krista Merry (University of Georgia, Warnell School of Forestry and Natural Resources), JUNE 2018
#               - adds a message to show the minimum and maximum date of the input fire data in the Arc dialog box
#               - incorporates Integrate function to tool
#               - removes polygons smaller than 2 acres
#               - calculates the fire frequency by month (annualize) with two separate formulas: time / years and time / years -1
#               - creates a text file containing descriptive statistics and two-parameter weibull distribution based on the fire frequency month/annualized
#               - generates a summary table of acres burned by fire type
#===========================================================================================================================================================
import arcpy, time, csv
from datetime import datetime


# Accept user input, set variables, and set environment.
sourceFC  = arcpy.GetParameterAsText(0) ## The user-specified source fire history polygon feature class
fireDateField = arcpy.GetParameterAsText(1) ## The user-specified date field in the fire history polygon feature class
growSeasonStart = arcpy.GetParameterAsText(2) ## The user-specified start date (month and day as MMDD) for the growing season
growSeasonEnd = arcpy.GetParameterAsText(3) ## The user-specified end date (month and day as MMDD) for the growing season
outFolder = arcpy.GetParameterAsText(4) ## The user-specified folder that will contain the output mdb and fc
sysDate   = time.strftime("%Y%m%d")  ## The current system date
sysTime   = time.strftime("%H%M")  ## The current system time
timeStamp = sysDate + "_" + sysTime  ## The date/time stamp
outMdb    = "FireFreqAndRecency_" + timeStamp + ".mdb" ## The name of the output mdb
outFC     = "FireFreqAndRecency_" + timeStamp
outFC_copy = "test_" + timeStamp  
arcpy.env.workspace = outFolder + "\\" + outMdb ## Set the workspace
arcpy.env.overwriteOutput = True ## Over-write output enabled
statsLog = outFolder + "//" + "firefreq_data_c" + ".csv"
statsLog2 = outFolder + "//" + "firefreq_data_s" + ".csv"
fireStatsLog = "FireFreq_Stats_C_" + timeStamp + ".csv"
fireStatsLog2 = "FireFreq_Stats_S_" + timeStamp + ".csv"

# Create the new output mdb, and copy the fire history polygon feature class to it.
arcpy.CreatePersonalGDB_management(outFolder, outMdb)
arcpy.env.workspace = outFolder + "\\" + outMdb ## Set the workspace
arcpy.CopyFeatures_management(sourceFC, "xxOriginalFC")
arcpy.Integrate_management("xxOriginalFC", "20 Meters") # Integrate the FC

# Create and field called NumberDate and convert date field to number.
arcpy.AddField_management("xxOriginalFC","NumberDate","LONG")
dateNumCalcFullDate = 'year( [' + fireDateField + '] ) & right(' + '"00"' + '& month( [' + fireDateField + '] ),2) & right(' + '"00"' + '& day( [' + fireDateField + '] ),2)'
arcpy.CalculateField_management("xxOriginalFC", "NumberDate", dateNumCalcFullDate)


# Calculate the length, in years, of the available fire history.
rows = arcpy.SearchCursor("xxOriginalFC", "", "", "NumberDate", "NumberDate A")
dateList = [] ## Create an empty list
for row in rows:
    if row.getValue("NumberDate") == 0: ## Identify NULL dates in input
        arcpy.AddWarning("A fire in the selected set had a NULL date and will not be used in this process...") ## Return warning message when NULL date is encountered 
    elif row.getValue("NumberDate") <> 0: ## Identify valid dates in input
        dateList.append(str(row.getValue("NumberDate"))) ## Append each fire's date to the list
del rows
minDate = dateList[0]
minYear = minDate[0:4]
maxDate = dateList[-1]
maxYear = maxDate[0:4]
fireHistoryYears = int(maxYear) - int(minYear) + 1 ## Calculate years of available fire history       
arcpy.AddMessage(" ")
arcpy.AddMessage("Fire History in years: " + str(fireHistoryYears))

# Create the initial scratch feature classes, and the output feature class.

arcpy.MultipartToSinglepart_management("xxOriginalFC", "xxSinglePart") ## Make sure that "xxOriginalFC" is single-part
arcpy.FeatureToLine_management("xxSinglePart", "xxPlanarizedPerimeters", "", "NO_ATTRIBUTES") ## Create a perimeter for each "xxOriginalFC" polygon
arcpy.FeatureToPolygon_management("xxPlanarizedPerimeters", outFC) ## Create the output FC as "planarized" fire mosaic tile polygons from fire perimeters
arcpy.SpatialJoin_analysis(outFC, "xxOriginalFC", "xxStacked", "JOIN_ONE_TO_MANY", "KEEP_COMMON", "", "WITHIN") ## Create "stacked" fire mosaic tile polygons

# Add new fields to outFC.
arcpy.AddField_management(outFC, "FireCount_All", "LONG")
arcpy.AddField_management(outFC, "RecentDate_All", "LONG")
arcpy.AddField_management(outFC, "FireFreq_All_C", "DOUBLE")
arcpy.AddField_management(outFC, "FireFreq_All_S", "DOUBLE")
arcpy.AddField_management(outFC, "FireCount_Growing", "LONG")
arcpy.AddField_management(outFC, "RecentDate_Growing", "LONG")
arcpy.AddField_management(outFC, "FireFreq_Grow_C", "DOUBLE")
arcpy.AddField_management(outFC, "FireFreq_Grow_S", "DOUBLE")
arcpy.AddField_management(outFC, "FireCount_Dormant", "LONG")
arcpy.AddField_management(outFC, "RecentDate_Dormant", "LONG")
arcpy.AddField_management(outFC, "FireFreq_Dor_C", "DOUBLE")
arcpy.AddField_management(outFC, "FireFreq_Dor_S", "DOUBLE")

# Calculate the overall fire count, most recent fire date, and fire frequency for each fire mosaic tile.

arcpy.AddMessage(" ")
arcpy.AddMessage("Summarizing fire count, most recent fire date, and fire frequency for ALL fires...")
arcpy.AddMessage(" ")
arcpy.Statistics_analysis("xxStacked", "in_memory\\sumAll", [["NumberDate", "Max"]], "TARGET_FID") ## Calc fire count and max date for each fire mosaic tile  
arcpy.JoinField_management(outFC, "ObjectID", "in_memory\\sumAll", "TARGET_FID", ["FREQUENCY", "Max_NumberDate"]) ## Attach fire count and max date fields
arcpy.Delete_management("in_memory\\sumAll")
arcpy.CalculateField_management(outFC, "FireCount_All", "[FREQUENCY]")
arcpy.CalculateField_management(outFC, "RecentDate_All", "[Max_NumberDate]")
arcpy.DeleteField_management(outFC, ["Max_NumberDate", "FREQUENCY"])

dateList2 = []
rows = arcpy.SearchCursor("xxStacked")
for row in rows:
    if row.getValue(fireDateField) is None:  
        arcpy.AddWarning("A fire in the selected set had a NULL date and will not be used in this process...") ## Return warning message when NULL date is encountered 
    elif row.getValue(fireDateField) is not None:
        dateList2.append(row.getValue(fireDateField))
del rows
dateList2.sort()
minAlla = dateList2[0]
maxAlla = dateList2[-1]
minMonthAlla = datetime.strptime(str(minAlla), "%Y-%m-%d %H:%M:%S")
maxMonthAlla = datetime.strptime(str(maxAlla), "%Y-%m-%d %H:%M:%S")
diffMonAlla = maxMonthAlla.month - minMonthAlla.month     # Calculate date month difference
diffYearAlla = maxMonthAlla.year - minMonthAlla.year      # Calculate date year difference
monthDiffAlla = (diffYearAlla *12) + diffMonAlla          # Calculate the total number of months
arcpy.AddMessage(" ")
arcpy.AddMessage("Fire History in months: " + str(monthDiffAlla))
arcpy.AddMessage(" ")

# CONSERVATIVE: Calculate the overal fire frequency (time / months minus 1)

with arcpy.da.UpdateCursor(outFC, ["FireFreq_All_C", "FireCount_All"]) as cursor:
    for row in cursor:
        if row[1] > 1:  #### LOOKS FOR FIRE COUNTS GREATER THAN 1 BECAUSE IF IT'S 1 OR ZERO THE CALCULATION WONT WORK
             row[0] = float((monthDiffAlla / (row[1] - 1)))/ 12   
        else:
            pass  ##### ASSIGNS A FIREFREQ OF NULL IF IT CANT CALC FIRE FREQ
        cursor.updateRow(row)
del cursor, row


# SIMPLE: Calculate the overall fire frequency(time / months)

with arcpy.da.UpdateCursor(outFC, ["FireFreq_All_S", "FireCount_All"]) as cursor:
    for row in cursor:
        if row[1] > 1:  #### LOOKS FOR FIRE COUNTS GREATER THAN 1 BECAUSE IF IT'S 1 OR ZERO THE CALCULATION WONT WORK
             row[0] = float((monthDiffAlla / (row[1])))/ 12   
        else:
            pass  ##### ASSIGNS A FIREFREQ OF NULL IF IT CANT CALC FIRE FREQ
        cursor.updateRow(row)
del cursor, row


# CONSERVATIVE: Calculate the growing season fire count, most recent growing season fire date, and growing season fire frequency by month (annualized) for each fire mosaic tile. Growing season.

arcpy.AddMessage("Summarizing fire count, most recent fire date, and fire frequency for GROWING SEASON fires...")
arcpy.AddMessage(" ")
expression = "mid(trim(str([NumberDate])), 5, 4) between '" + growSeasonStart + "' and '" + growSeasonEnd + "'"
arcpy.MakeFeatureLayer_management("xxStacked", "growingLyr")
arcpy.SelectLayerByAttribute_management("growingLyr", "NEW_SELECTION", expression) ## Select growing season fires
arcpy.Statistics_analysis("growingLyr", "in_memory\\sumGrowing", [["NumberDate", "Max"]], "TARGET_FID") ## Calc fire count and max date for each fire mosaic tile
arcpy.JoinField_management(outFC, "ObjectID", "in_memory\\sumGrowing", "TARGET_FID", ["FREQUENCY", "Max_NumberDate"]) ## Attach fire count and max date fields
arcpy.CalculateField_management(outFC, "FireCount_Growing", "[FREQUENCY]")
arcpy.CalculateField_management(outFC, "RecentDate_Growing", "[Max_NumberDate]")
arcpy.DeleteField_management(outFC, ["FREQUENCY", "Max_NumberDate"])

with arcpy.da.UpdateCursor(outFC, ["FireFreq_Grow_C", "FireCount_Growing"]) as cursor:
    for row in cursor:
        if row[1] > 1:
            if row[1] > 1:  #### LOOKS FOR FIRE COUNTS GREATER THAN 1 BECAUSE IF IT'S 1 OR ZERO THE CALCULATION WONT WORK
             row[0] = float((monthDiffAlla / (row[1] - 1)))/ 12   
        else:
            row[0] = None  ##### ASSIGNS A FIREFREQ OF NULL IF IT CANT CALC FIRE FREQ
        cursor.updateRow(row)
del cursor, row

# SIMPLE: Calculate the growing season fire count, most recent growing season fire date, and growing season fire frequency by month (annualized) for each fire mosaic tile. Growing season.

arcpy.AddMessage(" ")
expression = "mid(trim(str([NumberDate])), 5, 4) between '" + growSeasonStart + "' and '" + growSeasonEnd + "'"
arcpy.MakeFeatureLayer_management("xxStacked", "growingLyr")
arcpy.SelectLayerByAttribute_management("growingLyr", "NEW_SELECTION", expression) ## Select growing season fires
arcpy.Statistics_analysis("growingLyr", "in_memory\\sumGrowing", [["NumberDate", "Max"]], "TARGET_FID") ## Calc fire count and max date for each fire mosaic tile
arcpy.JoinField_management(outFC, "ObjectID", "in_memory\\sumGrowing", "TARGET_FID", ["FREQUENCY", "Max_NumberDate"]) ## Attach fire count and max date fields
arcpy.CalculateField_management(outFC, "FireCount_Growing", "[FREQUENCY]")
arcpy.CalculateField_management(outFC, "RecentDate_Growing", "[Max_NumberDate]")
arcpy.DeleteField_management(outFC, ["FREQUENCY", "Max_NumberDate"])

with arcpy.da.UpdateCursor(outFC, ["FireFreq_Grow_S", "FireCount_Growing"]) as cursor:
    for row in cursor:
        if row[1] > 1:
            if row[1] > 1:  #### LOOKS FOR FIRE COUNTS GREATER THAN 1 BECAUSE IF IT'S 1 OR ZERO THE CALCULATION WONT WORK
             row[0] = float((monthDiffAlla / (row[1])))/ 12   
        else:
            row[0] = None  ##### ASSIGNS A FIREFREQ OF NULL IF IT CANT CALC FIRE FREQ
        cursor.updateRow(row)
del cursor, row


# CONSERVATIVE: Calculate the dormant season fire count, most recent growing season fire date, and growing season fire frequency by month (annualized) for each fire mosaic tile. Dormant season.

arcpy.AddMessage("Summarizing fire count, most recent fire date, and fire frequency for DORMANT SEASON fires...")
arcpy.AddMessage(" ")
expression1 = "mid(trim(str([NumberDate])), 5, 4) not between '" + growSeasonStart + "' and '" + growSeasonEnd + "'"
arcpy.MakeFeatureLayer_management("xxStacked", "dormantLyr")
arcpy.SelectLayerByAttribute_management("dormantLyr", "NEW_SELECTION", expression1) ## Select growing season fires
arcpy.Statistics_analysis("dormantLyr", "in_memory\\sumDormant", [["NumberDate", "Max"]], "TARGET_FID") ## Calc fire count and max date for each fire mosaic tile
arcpy.JoinField_management(outFC, "ObjectID", "in_memory\\sumDormant", "TARGET_FID", ["FREQUENCY", "Max_NumberDate"]) ## Attach fire count and max date fields
arcpy.Delete_management("in_memory\\sumDormant")
arcpy.CalculateField_management(outFC, "FireCount_Dormant", "[FREQUENCY]")
arcpy.CalculateField_management(outFC, "RecentDate_Dormant", "[Max_NumberDate]")
arcpy.DeleteField_management(outFC, ["FREQUENCY", "Max_NumberDate"])

with arcpy.da.UpdateCursor(outFC, ["FireFreq_Dor_C", "FireCount_Dormant"]) as cursor: 
    for row in cursor:
        if row[1] > 1:
            if row[1] > 1:  #### LOOKS FOR FIRE COUNTS GREATER THAN 1 BECAUSE IF IT'S 1 OR ZERO THE CALCULATION WONT WORK
             row[0] = float((monthDiffAlla / (row[1] - 1)))/ 12   
        else:
            row[0] = None  ##### ASSIGNS A FIREFREQ OF NULL IF IT CANT CALC FIRE FREQ
        cursor.updateRow(row)
del cursor, row

# SIMPLE: Calculate the dormant season fire count, most recent growing season fire date, and growing season fire frequency by month (annualized) for each fire mosaic tile. Dormant season.

arcpy.AddMessage(" ")
expression1 = "mid(trim(str([NumberDate])), 5, 4) not between '" + growSeasonStart + "' and '" + growSeasonEnd + "'"
arcpy.MakeFeatureLayer_management("xxStacked", "dormantLyr")
arcpy.SelectLayerByAttribute_management("dormantLyr", "NEW_SELECTION", expression1) ## Select growing season fires
arcpy.Statistics_analysis("dormantLyr", "in_memory\\sumDormant", [["NumberDate", "Max"]], "TARGET_FID") ## Calc fire count and max date for each fire mosaic tile
arcpy.JoinField_management(outFC, "ObjectID", "in_memory\\sumDormant", "TARGET_FID", ["FREQUENCY", "Max_NumberDate"]) ## Attach fire count and max date fields
arcpy.Delete_management("in_memory\\sumDormant")
arcpy.CalculateField_management(outFC, "FireCount_Dormant", "[FREQUENCY]")
arcpy.CalculateField_management(outFC, "RecentDate_Dormant", "[Max_NumberDate]")
arcpy.DeleteField_management(outFC, ["FREQUENCY", "Max_NumberDate"])

with arcpy.da.UpdateCursor(outFC, ["FireFreq_Dor_S", "FireCount_Dormant"]) as cursor: 
    for row in cursor:
        if row[1] > 1:
            if row[1] > 1:  #### LOOKS FOR FIRE COUNTS GREATER THAN 1 BECAUSE IF IT'S 1 OR ZERO THE CALCULATION WONT WORK
             row[0] = float((monthDiffAlla / (row[1])))/ 12   
        else:
            row[0] = None  ##### ASSIGNS A FIREFREQ OF NULL IF IT CANT CALC FIRE FREQ
        cursor.updateRow(row)
del cursor, row


arcpy.CopyFeatures_management(outFC, outFC_copy)   # Make a copy of the fine FC to use to compute stats

# Print mimimum data and maximum data.

arcpy.AddMessage(" ")
arcpy.AddMessage("Minimum Date:" + minDate)
arcpy.AddMessage("Maximum Date:" + maxDate)
arcpy.AddMessage(" ")

# Write text file to be used for Weibull and Descriptive Stats - FireFreq_All_C 

arcpy.MakeFeatureLayer_management(outFC_copy, "tempLyr1")
arcpy.SelectLayerByAttribute_management("tempLyr1", "NEW_SELECTION", "[FireFreq_All_C] = 0 OR [FireFreq_All_C] is NULL")
arcpy.DeleteFeatures_management("tempLyr1")  ## Delete fire mosaic tiles with a frequency of 0
outFile = open(outFolder + '\\' + 'firefreq_data_c' + '.txt', "w")          #create text file 
rows = arcpy.SearchCursor("tempLyr1")       # create search cursor for FireFreq_ALL_C field
row = rows.next
for row in rows:
    outFile.write(str(row.FireFreq_All_C) + "\n")  #write values to text file
del row, rows
outFile.close()                                                     # closes the text file

# Calculate 2-Param Weibull and Descriptive Stats - FireFreq_All_C  
                             
from scipy.stats import weibull_min, sem
import numpy as np

data = np.loadtxt(outFolder + '\\' + 'firefreq_data_c' + '.txt')  # Use text file of fire frequencies for stats

n = len(data)
shape, loc, scale = weibull_min.fit(data, floc=0)
mean = np.mean(data)
median = np.median(data)
variance = np.var(data)
sd = np.std(data)
SEM = sem(data)

#  Write 2-Param Weibull and descriptive Stats to text file  

outFile2 = open(statsLog, 'w')
fields = ('Statistic', 'Value')
writer = csv.DictWriter(outFile2, fieldnames=fields, lineterminator = '\n') ## '\n' ---- no skipped rows in csv
writer.writeheader()
arcpy.AddMessage("Conservative: Weibull parameters")
arcpy.AddMessage(" ")
writer.writerow({'Statistic' : 'Weibull Shape', 'Value' : str(shape)})
arcpy.AddMessage("Conservative shape: " + str(shape))
writer.writerow({'Statistic' : 'Weibull Location', 'Value' : str(loc)})
arcpy.AddMessage("Conservative location: " + str(loc))
writer.writerow({'Statistic' : 'Weibull Scale', 'Value' : str(scale)})
arcpy.AddMessage("Conservative scale: " + str(scale))
arcpy.AddMessage("Conservative: Descriptive statistics")
arcpy.AddMessage(" ")
writer.writerow({'Statistic' : 'N', 'Value' : str(n)})
arcpy.AddMessage("Conservative N: " + str(n))
writer.writerow({'Statistic' : 'Mean', 'Value' : str(mean)})
arcpy.AddMessage("Conservative Mean: " + str(mean)) 
writer.writerow({'Statistic' : 'Median','Value' : str(median)})
arcpy.AddMessage("Conservative Median: " + str(median)) 
writer.writerow({'Statistic' : 'Variance', 'Value' : str(variance)})
arcpy.AddMessage("Conservative Variance: " + str(variance))
writer.writerow({'Statistic' : 'Standard Deviation', 'Value' : str(sd)})
arcpy.AddMessage("Conservative Standard Deviation: " + str(sd))
writer.writerow({'Statistic' : 'Standard Error', 'Value' : str(SEM)}) 
arcpy.AddMessage("Conservative Standard Error: " + str(SEM)) 
outFile2.close()   
arcpy.TableToTable_conversion(statsLog, outFolder, fireStatsLog)
arcpy.AddMessage(" ")

# Write text file to be used for Weibull and Descriptive Stats - FireFreq_All_S 

arcpy.MakeFeatureLayer_management(outFC_copy, "tempLyr3")
arcpy.SelectLayerByAttribute_management("tempLyr3", "NEW_SELECTION", "[FireFreq_All_S] = 0 OR [FireFreq_All_S] is NULL")
arcpy.DeleteFeatures_management("tempLyr3")  ## Delete fire mosaic tiles with a frequency of 0
outFile3 = open(outFolder + '\\' + 'firefreq_data_s' + '.txt', "w")          #create text file 
rows = arcpy.SearchCursor("tempLyr3")       # create search cursor for FireFreq_All_S field
row = rows.next
for row in rows:
    outFile3.write(str(row.FireFreq_All_S) + "\n")  #write values to text file
del row, rows
outFile3.close()
                            
# Calculate 2-Param Weibull and Descriptive Stats - FireFreq_All_S  
                             
from scipy.stats import weibull_min, sem
import numpy as np

data = np.loadtxt(outFolder + '\\' + 'firefreq_data_s' + '.txt')  # Use text file of fire frequencies for stats

n = len(data)
shape, loc, scale = weibull_min.fit(data, floc=0)
mean = np.mean(data)
median = np.median(data)
variance = np.var(data)
sd = np.std(data)
SEM = sem(data)

#  Write 2-Param Weibull and descriptive Stats to text file  

outFile4 = open(statsLog2, 'w')
fields = ('Statistic', 'Value')
writer = csv.DictWriter(outFile4, fieldnames=fields, lineterminator = '\n') ## '\n' ---- no skipped rows in csv
writer.writeheader()
arcpy.AddMessage("Simple: Weibull parameters")
arcpy.AddMessage(" ")
writer.writerow({'Statistic' : 'Weibull Shape', 'Value' : str(shape)})
arcpy.AddMessage("Simple shape: " + str(shape))
writer.writerow({'Statistic' : 'Weibull Location', 'Value' : str(loc)})
arcpy.AddMessage("Simple location: " + str(loc))
writer.writerow({'Statistic' : 'Weibull Scale', 'Value' : str(scale)})
arcpy.AddMessage("Simple scale: " + str(scale))
arcpy.AddMessage("Simple: Descriptive statistics")
arcpy.AddMessage(" ")
writer.writerow({'Statistic' : 'N', 'Value' : str(n)})
arcpy.AddMessage("Simple N: " + str(n))
writer.writerow({'Statistic' : 'Mean', 'Value' : str(mean)})
arcpy.AddMessage("Simple Mean: " + str(mean)) 
writer.writerow({'Statistic' : 'Median','Value' : str(median)})
arcpy.AddMessage("Simple Median: " + str(median)) 
writer.writerow({'Statistic' : 'Variance', 'Value' : str(variance)})
arcpy.AddMessage("Simple Variance: " + str(variance))
writer.writerow({'Statistic' : 'Standard Deviation', 'Value' : str(sd)})
arcpy.AddMessage("Simple Standard Deviation: " + str(sd))
writer.writerow({'Statistic' : 'Standard Error', 'Value' : str(SEM)}) 
arcpy.AddMessage("Simple Standard Error: " + str(SEM))
arcpy.AddMessage(" ")
outFile4.close()   
arcpy.TableToTable_conversion(statsLog2, outFolder, fireStatsLog2)

                         
# Clean up.
arcpy.AddMessage("Cleaning up...")
arcpy.AddMessage(" ")
arcpy.MakeFeatureLayer_management(outFC, "tempLyr")
arcpy.SelectLayerByAttribute_management("tempLyr", "NEW_SELECTION", "[FireCount_All] is NULL")
arcpy.DeleteFeatures_management("tempLyr") ## Delete fire mosaic tiles with a count of 0
arcpy.Delete_management("tempLyr")
arcpy.AddField_management(outFC, "Area_ac", "DOUBLE")
arcpy.CalculateField_management(outFC, "Area_ac", "!Shape.Area@Acre!", "PYTHON", "")  ### Recalculate Shape_Area field
arcpy.MakeFeatureLayer_management(outFC, "tempLyr2")
arcpy.SelectLayerByAttribute_management("tempLyr2", "NEW_SELECTION", "[Area_ac] < 2")
arcpy.DeleteFeatures_management("tempLyr2") ## Delete fire mosaic tiles with an acreage less than 2
arcpy.DeleteField_management(outFC, ["Area_ac"])

arcpy.Delete_management(outFolder + '\\' + 'firefreq_data_c' + '.txt')
arcpy.Delete_management(outFolder + '\\' + 'firefreq_data_s' + '.txt')
arcpy.Delete_management(statsLog)
arcpy.Delete_management(statsLog2)
arcpy.Delete_management(outFC_copy)

scratchList = arcpy.ListFeatureClasses("xx*")
for fc in scratchList:
    arcpy.Delete_management(fc)  ## Delete scratch files
del scratchList


# Report.
arcpy.AddMessage("OK, done...")
arcpy.AddMessage("The output feature class is filed as:")
arcpy.AddMessage("    " + arcpy.env.workspace + "\\" + outFC)


